#include <boost/math/special_functions/acosh.hpp>
#include <boost/math/special_functions/asinh.hpp>
#include <boost/math/special_functions/atanh.hpp>
#include "../boostmath/macros.hpp"

UNARY_BOOST_FUNCTION(acosh, double);
UNARY_BOOST_FUNCTION(asinh, double);
UNARY_BOOST_FUNCTION(atanh, double);
